Elasticipy package
==================

Submodules
----------

.. toctree::
   :maxdepth: 4

   Elasticipy.FourthOrderTensor
   Elasticipy.SecondOrderTensor
   Elasticipy.SphericalFunction
   Elasticipy.StressStrainTensors
   Elasticipy.Plasticity

Module contents
---------------

.. automodule:: Elasticipy
   :members:
   :undoc-members:
   :show-inheritance:
